==> 0.4.4.tar.gz: lib/src/key_base.dart <==
import 'dart:convert';
import 'dart:typed_data';

import 'package:bs58check/bs58check.dart';
import 'package:crypto/crypto.dart';
import 'package:pointycastle/digests/ripemd160.dart';
import "package:pointycastle/ecc/curves/secp256k1.dart";
import 'package:pointycastle/src/utils.dart';

import './exception.dart';

/// abstract AMA Key
abstract class AMAKey {
  static final String SHA256X2 = 'sha256x2';
  static final int VERSION = 0x80;
  static final ECCurve_secp256k1 secp256k1 = ECCurve_secp256k1();

  String? keyType;

  /// Decode key from string format
  static Uint8List decodeKey(String keyStr, [String? keyType]) {
    Uint8List buffer = base58.decode(keyStr);

    Uint8List checksum = buffer.sublist(buffer.length - 4, buffer.length);
    Uint8List key = buffer.sublist(0, buffer.length - 4);

    Uint8List newChecksum;
    if (keyType == SHA256X2) {
      newChecksum = sha256x2(key).sublist(0, 4);
    } else {
      Uint8List check = key;
      if (keyType != null) {
        check = concat(key, Uint8List.fromList(utf8.encode(keyType)));
      }
      newChecksum = RIPEMD160Digest().process(check).sublist(0, 4);
    }
    if (decodeBigIntWithSign(1, checksum) !=
        decodeBigIntWithSign(1, newChecksum)) {
      throw InvalidKey("checksum error");
    }
    return key;
  }

  /// Encode key to string format using base58 encoding
  static String encodeKey(Uint8List key, [String? keyType]) {
    if (keyType == SHA256X2) {
      Uint8List checksum = sha256x2(key).sublist(0, 4);
      return base58.encode(concat(key, checksum));
    }

    Uint8List keyBuffer = key;
    if (keyType != null) {
      keyBuffer = concat(key, Uint8List.fromList(utf8.encode(keyType)));
    }
    Uint8List checksum = RIPEMD160Digest().process(keyBuffer).sublist(0, 4);
    return base58.encode(concat(key, checksum));
  }

  /// Do SHA256 hash twice on the given data
  static Uint8List sha256x2(Uint8List data) {
    Digest d1 = sha256.convert(data);
    Digest d2 = sha256.convert(d1.bytes);
    return Uint8List.fromList(d2.bytes);
  }

  static Uint8List concat(Uint8List p1, Uint8List p2) {
    List<int> keyList = p1.toList();
    keyList.addAll(p2);
    return Uint8List.fromList(keyList);
  }

  static List<int> toSigned(Uint8List bytes) {
    List<int> result = <int>[];
    for (int i = 0; i < bytes.length; i++) {
      int v = bytes[i].toSigned(8);
      //TODO I don't know why, just guess...
      if (i == 0 && v < 0) {
        result.add(0);
      }
      result.add(v);
    }
    return result;
  }
}

==> 1.0.0.tar.gz: lib/src/key_base.dart <==
import 'dart:typed_data';

import 'package:base58check/base58.dart';
import 'package:base58check/base58check.dart';
import 'package:crypto/crypto.dart';
import 'package:pointycastle/digests/ripemd160.dart';
import 'package:pointycastle/src/utils.dart';
import "package:pointycastle/ecc/curves/secp256k1.dart";

import './exception.dart';

/// abstract VIZ Key
abstract class VIZKey {
  static final String SHA256X2 = 'sha256x2';
  static final int VERSION = 0x80;
  static final ECCurve_secp256k1 secp256k1 = ECCurve_secp256k1();

  static final base58 = Base58Codec(Base58CheckCodec.BITCOIN_ALPHABET);

  /// Decode key from string format
  static Uint8List decodeKey(String keyStr, [String keyType]) {
    Uint8List buffer = Uint8List.fromList(base58.decode(keyStr));

    Uint8List checksum = buffer.sublist(buffer.length - 4, buffer.length);
    Uint8List key = buffer.sublist(0, buffer.length - 4);

    Uint8List newChecksum;
    if (keyType == SHA256X2) {
      newChecksum = sha256x2(key).sublist(0, 4);
    } else {
      Uint8List check = key;
      newChecksum = RIPEMD160Digest().process(check).sublist(0, 4);
    }
    if (decodeBigInt(checksum) != decodeBigInt(newChecksum)) {
      throw InvalidKey("Invalid checksum: $checksum");
    }
    return key;
  }

  /// Encode key to string format using base58 encoding
  static String encodeKey(Uint8List key, [String keyType]) {
    if (keyType == SHA256X2) {
      Uint8List checksum = sha256x2(key).sublist(0, 4);
      return base58.encode(concat(key, checksum));
    }

    Uint8List keyBuffer = key;
    Uint8List checksum = RIPEMD160Digest().process(keyBuffer).sublist(0, 4);
    return base58.encode(concat(key, checksum));
  }

  /// Do SHA256 hash twice on the given data
  static Uint8List sha256x2(Uint8List data) {
    Digest d1 = sha256.convert(data);
    Digest d2 = sha256.convert(d1.bytes);
    return d2.bytes;
  }

  static Uint8List concat(Uint8List p1, Uint8List p2) {
    List<int> keyList = p1.toList();
    keyList.addAll(p2);
    return Uint8List.fromList(keyList);
  }

  static List<int> toSigned(Uint8List bytes) {
    List<int> result = List();
    for (int i = 0; i < bytes.length; i++) {
      int v = bytes[i].toSigned(8);
      //TODO I don't know why, just guess...
      if (i == 0 && v < 0) {
        result.add(0);
      }
      result.add(v);
    }
    return result;
  }
}
